import cv2
import os

# 配置参数
video_path = 'och4f1h6sXiQEl9Qzj0FXRqqTLFCASi7dIAJy6.mp4'
output_dir = 'output'
start_sec = 61   # 开始时间（秒）
end_sec = 63     # 结束时间（秒）

# 创建输出目录
os.makedirs(output_dir, exist_ok=True)

# 打开视频文件
cap = cv2.VideoCapture(video_path)
if not cap.isOpened():
    raise Exception("无法打开视频文件")

# 获取视频信息
fps = cap.get(cv2.CAP_PROP_FPS)
total_frames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
duration = total_frames / fps

# 验证时间范围
if start_sec >= duration:
    cap.release()
    raise ValueError("开始时间超过视频时长")

# 计算目标帧范围
start_frame = int(start_sec * fps)
end_frame = min(int(end_sec * fps), total_frames - 1)

# 跳转到起始帧
cap.set(cv2.CAP_PROP_POS_FRAMES, start_frame)
current_frame = int(cap.get(cv2.CAP_PROP_POS_FRAMES))

# 处理跳转不准确的情况
while current_frame < start_frame:
    ret = cap.grab()
    if not ret:
        break
    current_frame += 1

# 提取并保存帧
frame_count = 0
while current_frame <= end_frame:
    ret, frame = cap.read()
    if not ret:
        break
    
    # 修改点1：保存为PNG格式
    output_path = os.path.join(output_dir, f'frame_{current_frame:06d}.png')
    
    # 修改点2：添加PNG压缩参数（压缩级别0-9，默认1）
    cv2.imwrite(
        output_path, 
        frame, 
        [cv2.IMWRITE_PNG_COMPRESSION, 3]  # 推荐压缩级别3-5
    )
    
    current_frame += 1
    frame_count += 1

# 释放资源
cap.release()
print(f"成功保存 {frame_count} 帧到 {output_dir} 目录")
